@@ -3,6 +3,8 @@
 #' @description getAuth authenticates the R app at the Google authentication server using OAUTH2 and receives the client token.
 #' Usually you need not to run getAuth() explicitly since the whole authentication process is managed by \code{\link{doAuth}}.
 #' 
+#' @importFrom utils browseURL
+#' 
 #' @return Client token from Google authentication server.
 #' Dataframe with the credential information which is cached in working space 
 #' and optionally saved as RData file in current working directory.
@@ -48,7 +50,7 @@ getAuth = function() {
                  'access_type=offline&',
                  'approval_prompt=force', sep='', collapse='')
     cert <- system.file("CurlSSL", "ca-bundle.crt", package = "RCurl")#SSL Certificate Fix for Windows
-    RCurl::getURL(url, cainfo=cert)
+    RCurl::getURL(url, cainfo=cert, ssl.verifypeer = TRUE) # Explicitly setting certificate verification for an error in OS X
     browseURL(url)
     # Manual next-step: input code-parameter to c.token variable and run loadToken()
     cat('Authentication process needs your Client token in order to receive the access token from the API. Copy the Client token from your webbrowser and paste it here.')
